#
# spec file for package netcdf-cxx4
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects

ExcludeArch:    s390 s390x i586 %arm

%define libname(s:)   libnetcdf_c++4%{?-s:-%{-s*}}

Name:           netcdf-cxx4
Version:        4.3.1
%global _ver 4_3_1
Release:        8.1
Summary:        C++ library for the Unidata network Common Data Form version 4
License:        NetCDF
Group:          Productivity/Scientific/Other
URL:            http://www.unidata.ucar.edu/software/netcdf/
Source0:        http://www.unidata.ucar.edu/downloads/netcdf/ftp/netcdf-cxx4-%{version}.tar.gz
Patch0:         netcdf-cxx4-testsuite_bigendian.patch
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(netcdf)

%description
NetCDF4 (network Common Data Form) is a set of software libraries and
machine-independent data formats that support the creation, access, and sharing
of array-oriented scientific data.

This package provides the C++ API.

%package -n %{libname -s %{sover}}
Summary:        C++ library for the Unidata network Common Data Form version 4
Group:          System/Libraries
Provides:       libnetcdf%{sover}:%{_libdir}/libnetcdf_c++.so.%{sover}

%description -n %{libname -s %{sover}}
NetCDF4 (network Common Data Form) is a set of software libraries and
machine-independent data formats that support the creation, access, and sharing
of array-oriented scientific data.

This package provides the C++ API.

%package -n %{libname}-devel
Summary:        Development files for netcdf_c++
Group:          Development/Libraries/C and C++
Provides:       libnetcdf-devel:%{_libdir}/libnetcdf_c++.so
Requires:       %{libname -s %{sover}} = %{version}
Obsoletes:      %{name}-tools < %{version}
Provides:       %{name}-tools = %{version}

%description -n %{libname}-devel
This package contains the netcdf_c++4 header files and shared devel libs.

%prep
%setup -q -n %{name}-%{version}
%ifarch ppc ppc64 s390 s390x
%patch -P 0 -p1
%endif

%build
%configure \
     --disable-static
make %{?_smp_mflags}

%install
%make_install
rm %{buildroot}%{_libdir}/libnetcdf_c++4.la

%check
make check || {
	cat cxx4/test-suite.log
	exit 1
}

%post -n %{libname -s %{sover}} -p /sbin/ldconfig

%postun -n %{libname -s %{sover}}
/sbin/ldconfig

%files -n %{libname -s %{sover}}
%license COPYRIGHT
%doc README.md RELEASE_NOTES.md
%{_libdir}/libnetcdf_c++4.so.%{sover}
%{_libdir}/libnetcdf_c++4.so.%{sover}.*

%files -n %{libname}-devel
%license COPYRIGHT
%doc README.md RELEASE_NOTES.md
%{_includedir}/nc*.h
%{_includedir}/netcdf
%{_bindir}/ncxx4-config
%{_libdir}/pkgconfig/netcdf-cxx4.pc
%{_libdir}/libnetcdf_c++4.so
# Do not add plugins for now
%exclude %{_libdir}/libh5bzip2.*

%changelog
* Tue Apr  1 2025 Egbert Eich <eich@suse.com>
- Remove support for gnu-hpc build flavors (bsc#1239982).
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Dec 12 2022 Egbert Eich <eich@suse.com>
- Add BuildRequires for libnetcdf-<compiler_family>-hpc explicitly
  so that %%%%{requires_eq ..} is able to find the package and obtain
  the version number (boo#1206334).
* Thu Jul  1 2021 Egbert Eich <eich@suse.com>
- Move ncxx4-config to the netcdf-cxx4.
  * Remove the *-tools package (bsc1187910).
* Wed Apr  7 2021 Dirk Müller <dmueller@suse.com>
- do not own the includedir - it comes from the filesystem package
* Wed Dec  9 2020 Egbert Eich <eich@suse.com>
- Change 'Requires:' to netcdf to %%requires_eq to match the exact
  version of hdf5 in the dependency. This should take care of
  HPC packages ignoring proper ABI versioning (boo#1179521).
* Fri Sep 11 2020 Egbert Eich <eich@suse.com>
- Add build support for gcc8/9/10 to HPC build (bsc#1174439).
* Wed Oct  2 2019 Ana Guerrero Lopez <aguerrero@suse.com>
- Update to version 4.3.1, (jsc#SLE-9959), see changes at:
  * https://www.unidata.ucar.edu/blogs/news/entry/netcdf-c-4-3-1
- Use -ffat-lto-objects to provide a proper static library.
- Spec file cleanup
* Mon Apr 30 2018 eich@suse.com
- (Temporarily) disable fpr S390* as a check test for netcdf fails
  currently on BE (bsc#1091474).
* Fri Apr 27 2018 eich@suse.com
- Disable non-HPC builds on non-openSUSE systems:
  a. currently only SUSE products/projects are supported/
  b. non-HPC builds are not and have never been supported on SLE,
    on openSUSE they are provided for compatibility reasons
    (bsc#1091223).
* Thu Mar 22 2018 ro@suse.de
- add netcdf-cxx4-testsuite_bigendian.patch (bsc#1086393)
  skip problematic testcases on bigendian architectures for now
  looks like netcdf-4.4.X is lacking proper support
- output test log in case of error in check section of specfile
* Fri Feb  9 2018 eich@suse.com
- Fix summary in module files (bnc#1080259).
* Fri Jan  5 2018 eich@suse.com
- Switch from gcc6 to gcc7 as additional compiler flavor for HPC on SLES.
- Fix library package requires - use HPC macro (boo#1074890).
* Tue Nov 14 2017 eich@suse.com
- Fix modules file: only use %%hpc_bindir if it really exists
  - installing the tool package is optional.
- Translate '-' to '_' for env-variable.
- Require lua-lmod.
- Add Requires for library package to tools package.
* Fri Nov 10 2017 eich@suse.com
- Add Requires: for the netcdf library/devel package to the
  netcdf-cxx4 library/devel package for HPC.
* Mon Oct 30 2017 eich@suse.com
- Add and fix 'standard' build.
* Wed Oct 25 2017 eich@suse.com
- Fix Requires for the devel package.
* Mon Oct 23 2017 eich@suse.com
- Fix buildrequires for compiler_families where c_f_ver is set.
* Sat Oct 14 2017 eich@suse.com
- Add static library package.
* Mon Aug 28 2017 eich@suse.com
- Make package multibuild aware and add support for HPC environment
  modules (FATE#321719).
* Mon Jul 25 2016 jengelh@inai.de
- Summary/RPM group update.
- Rename soname macro because it really just contains the version.
* Wed Jul 20 2016 toddrme2178@gmail.com
- Fix dependency numbering issue in spec file.
* Thu Jul 14 2016 toddrme2178@gmail.com
- Initial version
